pub struct Dirs { /* private fields */ }Expand description
The two directories, project-relative and normalised.
Implementations
Sourceimpl Dirs
impl Dirs
Sourcepub fn resolve(root_manifest: &Value) -> Result<Dirs, String>
pub fn resolve(root_manifest: &Value) -> Result<Dirs, String>
From the root manifest, the environment and the global config.
Sourcepub fn resolve_with(
root_manifest: &Value,
env: impl Fn(&str) -> Option<String>,
global: impl Fn(&str) -> Option<Value>,
) -> Result<Dirs, String>
pub fn resolve_with( root_manifest: &Value, env: impl Fn(&str) -> Option<String>, global: impl Fn(&str) -> Option<Value>, ) -> Result<Dirs, String>
resolve with the environment and the global config injected.
Sourcepub fn vendor_rel(&self) -> &str
pub fn vendor_rel(&self) -> &str
vendor by default.
pub fn vendor_dir(&self, root: &Path) -> PathBuf
pub fn bin_dir(&self, root: &Path) -> PathBuf
Sourcepub fn composer_dir(&self, root: &Path) -> PathBuf
pub fn composer_dir(&self, root: &Path) -> PathBuf
<vendor-dir>/composer.