pub fn plugin_allowed(manifest: &Value, package: &str) -> PluginVerdictExpand description
Verdict for package under the project config merged with the global one.
pub fn plugin_allowed(manifest: &Value, package: &str) -> PluginVerdictVerdict for package under the project config merged with the global one.