array_merge_recursive

Function array_merge_recursive 

pub fn array_merge_recursive(a: &Value, b: &Value) -> Value
array_merge_recursive($a, $b): a string key present in both merges recursively when both values are arrays, otherwise the two values become a list ([a, b]; a list on one side takes the other side’s value appended, in order); integer keys append.