pub struct Store { /* private fields */ }Implementations
Sourceimpl Store
impl Store
pub fn at(root: PathBuf) -> Store
pub fn default_location() -> Store
Sourcepub fn entry_path(
&self,
name: &str,
version: &str,
dist_ref: Option<&str>,
) -> PathBuf
pub fn entry_path( &self, name: &str, version: &str, dist_ref: Option<&str>, ) -> PathBuf
Entry key: version + first 12 hex chars of the dist reference, sanitised for the file system.
Sourcepub fn ensure(
&self,
name: &str,
version: &str,
dist_ref: Option<&str>,
zip_bytes: &[u8],
) -> Result<PathBuf>
pub fn ensure( &self, name: &str, version: &str, dist_ref: Option<&str>, zip_bytes: &[u8], ) -> Result<PathBuf>
Ensures the entry is present, extracting it if needed. Returns the path of the extracted tree.
pub fn contains( &self, name: &str, version: &str, dist_ref: Option<&str>, ) -> bool