pub fn install_appendix(
project_dir: &Path,
install_path: &Path,
dist_url: &str,
transport_options: Option<&Value>,
) -> Result<String>Expand description
getInstallOperationAppendix: what follows the operation line —
: Source already present when the install path already resolves to
the source, else the strategy and the dist url as written.