pub fn array_merge_recursive(a: &Value, b: &Value) -> ValueExpand description
array_merge_recursive($a, $b): a string key present in both merges
recursively when both values are arrays, otherwise the two values
become a list ([a, b]; a list on one side takes the other side’s
value appended, in order); integer keys append.